==> openGion6.5.0.0_src.zip: gf/src/org/opengion/hayabusa/resource/CalendarQuery.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.hayabusa.resource;

/**
 * カレンダＤＢを検索する為の クエリインターフェースです。
 *
 * カレンダデータは、ＤＢまたは標準のカレンダより休日を求めることができます。
 *
 * @og.rev 3.6.0.0 (2004/09/17) 新規作成
 * @og.group リソース管理
 *
 * @version  4.0
 * @author   Kazuhiko Hasegawa
 * @since    JDK5.0,
 */
public interface CalendarQuery {

	/**
	 * ４つの引数を受け取り、整合性チェックを行います。
	 * 引数は、各クラスによって使用するカラム名(意味)が異なります。
	 * また、すべての引数をチェックするのではなく、クラス毎に、チェックする
	 * カラムの数は、異なります。
	 * ※ 引数が正しくない場合は、HybsSystemException を発行します。
	 *
	 * @param	arg1  	データベース検索時の第１引数
	 * @param	arg2  	データベース検索時の第２引数
	 * @param	arg3  	データベース検索時の第３引数
	 * @param	arg4  	データベース検索時の第４引数
	 *
	 * @return	入力パラメータに応じた配列文字列(必要分のみ配列化)
	 */
	String[] checkArgment( String arg1,String arg2,String arg3,String arg4 ) ;

	/**
	 * データベース検索の為の Select 文を返します。
	 * 引数リストとともに、使用します。
	 *
	 * @return データベース検索の為の Select 文
	 *
	 */
	String getQuery() ;

	/**
	 * データベースの持ち方を指定します。
	 * 持ち方がフラット(横持ち=1～31の日付をカラムで持つ)の場合、trueを返します。
	 * 縦持ち(日付単位で、行情報として持つ)場合は、false です。
	 *
	 * @return DBの持ち方がフラット(横持ち=1～31の日付をカラムで持つ)の場合、true
	 *
	 */
	boolean isFlatTable() ;
}

==> openGion7.2.3.1_src.zip: gf/src/org/opengion/hayabusa/resource/CalendarQuery.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.hayabusa.resource;

/**
 * カレンダＤＢを検索する為の クエリインターフェースです。
 *
 * カレンダデータは、ＤＢまたは標準のカレンダより休日を求めることができます。
 *
 * @og.rev 3.6.0.0 (2004/09/17) 新規作成
 * @og.group リソース管理
 *
 * @version  4.0
 * @author   Kazuhiko Hasegawa
 * @since    JDK5.0,
 */
public interface CalendarQuery {

	/**
	 * ４つの引数を受け取り、整合性チェックを行います。
	 * 引数は、各クラスによって使用するカラム名(意味)が異なります。
	 * また、すべての引数をチェックするのではなく、クラス毎に、チェックする
	 * カラムの数は、異なります。
	 * ※ 引数が正しくない場合は、HybsSystemException を発行します。
	 *
	 * @og.rev 6.9.9.3 (2018/09/25) 可変引数に変更します(PMD Rather than using a lot of String arguments, consider using a container object for those values.)。
	 *
	 * @param	args  	データベース検索時の引数( CDJGS:事業所コード のみ)
//	 * @param	arg1  	データベース検索時の第１引数
//	 * @param	arg2  	データベース検索時の第２引数
//	 * @param	arg3  	データベース検索時の第３引数
//	 * @param	arg4  	データベース検索時の第４引数
	 *
	 * @return	入力パラメータに応じた配列文字列(必要分のみ配列化)
	 */
//	String[] checkArgment( String arg1,String arg2,String arg3,String arg4 ) ;
	String[] checkArgment( final String... args );

	/**
	 * データベース検索の為の Select 文を返します。
	 * 引数リストとともに、使用します。
	 *
	 * @return データベース検索の為の Select 文
	 *
	 */
	String getQuery() ;

	/**
	 * データベースの持ち方を指定します。
	 * 持ち方がフラット(横持ち=1～31の日付をカラムで持つ)の場合、trueを返します。
	 * 縦持ち(日付単位で、行情報として持つ)場合は、false です。
	 *
	 * @return DBの持ち方がフラット(横持ち=1～31の日付をカラムで持つ)の場合、true
	 *
	 */
	boolean isFlatTable() ;
}
